"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const baseProj_1 = require("./baseProj");
const globalData_1 = require("../model/globalData");
const fs_1 = require("fs");
const ProjectType_1 = require("../model/ProjectType");
const fs_i_1 = require("fs-i");
class WebpackProj extends baseProj_1.BaseProj {
    getQuestions() {
        let questionList = [];
        return questionList;
    }
    run() {
        return __awaiter(this, void 0, void 0, function* () {
            if (globalData_1.GlobalData.projectType !== ProjectType_1.ProjectType.webpack) {
                return;
            }
            let projPath = `${process.cwd()}/${globalData_1.GlobalData.projectName}`;
            this.saveWebpackConfig(projPath);
            this.savePackage(projPath);
        });
    }
    saveWebpackConfig(path) {
        return __awaiter(this, void 0, void 0, function* () {
            let file = `${path}/webpack.config.ts`;
            let fileContent = `
    import * as webpack from "webpack";
    import * as path from "path";
    
    let config: webpack.Configuration = {
      entry: {
        index: "./src/index.ts"
      },
      output: {
        path: path.resolve(__dirname, "es"),
        filename: "[name].js"
      },
      module: {
        rules: [{ test: /\.ts$/, use: "ts-loader" }]
      },
      target: "node",
      resolve: {
        extensions: [".ts", ".js"]
      },
      externals: {
        "fs-extra": "require('fs-extra')"
      }
    };
    
    export default config;
    
    
    `;
            yield fs_1.writeFileSync(file, fileContent);
        });
    }
    savePackage(path) {
        return __awaiter(this, void 0, void 0, function* () {
            let file = `${path}/package.json`;
            let fileContent = yield fs_i_1.readFileUtf8(file);
            let json = JSON.parse(fileContent);
            json.devDependencies["@types/webpack"] = "^3.8.1";
            json.devDependencies["webpack"] = "^3.10.0";
            json.devDependencies["ts-loader"] = "^3.2.0";
            json.scripts["tsBuild"] = "webpack";
            fileContent = JSON.stringify(json, null, 2);
            yield fs_1.writeFileSync(file, fileContent);
        });
    }
}
exports.WebpackProj = WebpackProj;
//# sourceMappingURL=webpackProj.js.map